@@ -1,7 +1,7 @@
 ##    _____  _____
 ##   |  __ \|  __ \    AUTHOR: Pedro Rivero
 ##   | |__) | |__) |   ---------------------------------
-##   |  ___/|  _  /    DATE: February 23, 2021
+##   |  ___/|  _  /    DATE: May 11, 2021
 ##   | |    | | \ \    ---------------------------------
 ##   |_|    |_|  \_\   https://github.com/pedrorrivero
 ##
@@ -23,7 +23,14 @@
 __author__ = "Pedro Rivero"
 __copyright__ = "Copyright (c) 2021 Pedro Rivero"
 __license__ = "Apache-2.0"
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 from ._qiskit_bit_generator import QiskitBitGenerator
-from ._qrng import Qrng
+from .qrng import Qrng
+from .quantum_bit_generator import QuantumBitGenerator
+
+__all__ = [
+    "QiskitBitGenerator",
+    "Qrng",
+    "QuantumBitGenerator",
+]
